# http://www.28lines.com/?p=8

import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from web.tests.runtests import runtests

        runtests()


def get_data_files(*args, **kwargs):
    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name):
            rel_dirpath = re.sub("^" + pkg_name + '/', '', dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='office.cogema.it',
    version="1.0",
    description='Thunder custom Django CMS',
    author='ThunderSystems',
    url='http://hg.thundersystems.it/jmb/office.cogema.it',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="web.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'django==1.5.5',
        'django-cms>=2.4',
        'django-filer>=0.9.3',
        'django_extensions',
        'easy_thumbnails==1.4',
        'django-reversion==1.6.3',
        'cmsplugin-filer==0.9',
        'pillow',
        'jmb.core>=0.4.4',
        'django-tinymce',
        'jmb.cms-misc',
        'django-admin-tools',
        'jmb.l10n',
        'jmb.i18n>=0.5.1',
        'jmb.ticket',
        'jmb.project',
        'cogema.impianto',
        'cogema.contratto',
        'cogema.azienda',
        'django-autocomplete-light==1.4.9',
        'PyPDF2',
        'reportlab',
        ],
    package_data=get_data_files('web')
)

