# -*- coding: utf-8 -*-
import os

from django.utils.translation import ugettext_lazy as _

gettext = lambda s: s

SETTINGS_PATH = os.path.abspath(os.path.dirname(__file__))
PROJECT_PATH = os.path.dirname(SETTINGS_PATH)

CMS_ENABLED = False

DEBUG = True
TEMPLATE_DEBUG = DEBUG

ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MANAGERS = ADMINS

TICKET_SEND_EMAIL = False

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = 'Europe/Rome'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'it'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.
USE_L10N = True

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = False

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = os.path.join(PROJECT_PATH, "media")

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = '/media/'

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = os.path.join(PROJECT_PATH, "static_auto")

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    os.path.join(PROJECT_PATH, "static_manual"),
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
#    'django.contrib.staticfiles.finders.DefaultStorageFinder',
    'dajaxice.finders.DajaxiceFinder',
)

# Make this unique, and don't share it with anybody.
SECRET_KEY = 'mk2l$f*=f)s@ol78k9zj3(dyd^0+aour1g4p)s@#a%k#1+#vys'

LOCALE_PATHS = (
    os.path.join(PROJECT_PATH, "locale")
    )
# List of callables that know how to import templates from various sources.
TEMPLATE_LOADERS = (
    'django.template.loaders.filesystem.Loader',
    'django.template.loaders.app_directories.Loader',
    'django.template.loaders.eggs.Loader',
    'jmb.core.templateloaders.apptemplate.Loader',  # necessario per advanced_search
)

TEMPLATE_CONTEXT_PROCESSORS = (
    'django.contrib.auth.context_processors.auth',
    'django.core.context_processors.debug',
    'django.core.context_processors.i18n',
    'django.core.context_processors.media',
    'django.core.context_processors.request',
    'django.contrib.messages.context_processors.messages',
    'django.core.context_processors.static',
#    'jmb.core.context_processors.admin_theme_less',

)

MIDDLEWARE_CLASSES = (
    'django.middleware.common.CommonMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
#    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'jmb.core.middleware.thread_local.ThreadLocals',
    # Uncomment the next line for simple clickjacking protection:
    # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'web.urls'

# Python dotted path to the WSGI application used by Django's runserver.
# WSGI_APPLICATION = 'mycmsproject.wsgi.application'

TEMPLATE_DIRS = (
    os.path.join(PROJECT_PATH, "templates")
    # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

INSTALLED_APPS = (
    'jmb.core', # jumbo deve essere come prima applicazione perche sovrascrive i template di admin
    'admin_tools',
#    'admin_tools.theming', # sminchia il 6tema bootstrap
    'admin_tools.menu',
    'admin_tools.dashboard',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'south',
    'django_extensions',
    'easy_thumbnails',
    'web',
    'dajaxice',
    'dajax',
    # admin:
    'django.contrib.admin',
    'django.contrib.comments',
    # admin docs:
    # 'django.contrib.admindocs',
    'django_extensions',
    'django_filters',
    'autocomplete_light',
    'jmb.i18n',
    'jmb.l10n',
    'jmb.organization',
    'jmb.address',
    'jmb.payment',
    'jmb.office',
    'jmb.vat',
    'jmb.currency',
    'jmb.carriage',
    'jmb.bank',
#    'jmb.fax',
#    'jmb.event',
    'jmb.project',
    'jmb.ticket',
    'cogema.impianto',
    'cogema.contratto',
    'cogema.azienda',
    'tinymce',
    )


# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        },
        'file':{
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '/var/log/django/office.cogema.it.log',
        },
        'fileimport':{
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '/var/log/django/office.cogema.it-import.log',
        },
    },

    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },

        'jmb': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'DEBUG',
        },
        'cogema': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'DEBUG',
        },
        'cogema.import': {
            'handlers': ['fileimport'],
            'propagate': True,
            'level': 'DEBUG',
        }
    }
}
ADMIN_TOOLS_INDEX_DASHBOARD = 'web.dashboard.JumboDashboard'
ADMIN_TOOLS_MENU = 'web.jmenu.JumboMenu'

#: Configurazione choices
ORGANIZATION_ORGANIZATIONTYPE_DEF = (
    ("com", _("owner company"),),
    ("cus", _("customer"),),
    ("sup", _("supplier"),),
    ("amm", _("amministratore"),), # aggiunto volutamente in italiano per COGEMA
)
TICKET_TICKET_STATUS_CODES = (
    (0, _('closed')),
    (1, _('open')),
)
TICKET_TICKET_PRIORITY_CODES = (
    (0, _('molto urgente')),
    (1, _('in giornata')),
    (2, _('importante')),
    (3, _('quando possibile')),
    (4, _('lavoro da preventivo')),
    (5, _('manutenzione da contratto')),
)

TICKET_TICKET_REVERSE_NAME = 'admin:contratto_cogemaproject_change'

CACHE_BACKEND = 'caching.backends.locmem://'
ALLOWED_HOSTS = ['*']
ADDRESS_ADDRESS_TYPE_CHOICES = (
    ## Zucchetti non esporta il 'dug'
    (7, ''),
)
if CMS_ENABLED:
    from cms_settings import *
